@@ -77,7 +77,7 @@ _option="${1}";
 
 _intelStr="Intel GPU (Power Save Mode)";
 _nvidiaStr="Nvidia GPU (Performance Mode)";
-_hybridStr="Hybrid GPU (On-Demand Mode)";
+_hybridStr="Hybrid GPU (On-Demand Mode)<br><br>Not Recommended if Using<br>External Monitors";
 _kdiagExeStr="$(command -v kdialog)";
 _zenityExeStr="$(command -v zenity)";
 
